#!/usr/bin/python3

from setuptools import setup
import codecs
import glob
import re
import os

here = os.path.abspath(os.path.dirname(__file__))


def read(*parts):
    return codecs.open(os.path.join(here, *parts), 'r').read()


def find_version(*file_paths):
    version_file = read(*file_paths)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


data_files = [
    ("share/oraculum", ["alembic.ini"]),
    ("share/oraculum/alembic", ["alembic/README",
                                "alembic/env.py",
                                "alembic/script.py.mako"]),
    ("share/oraculum/alembic/versions", glob.glob("alembic/versions/*.py")),
    ("share/docs/oraculum", glob.glob("conf/*")),
    ("lib/systemd/system", glob.glob("conf/*.service")),
]


setup(name='oraculum',
      version=find_version('oraculum', '__init__.py'),
      description='Salty salmon...',
      author='Josef Skladanka',
      author_email='jskladan@redhat.com',
      license='GPLv2+',
      packages=['oraculum', 'oraculum.action_providers', 'oraculum.controllers', 'oraculum.models', 'oraculum.utils'],
      package_dir={'oraculum': 'oraculum'},
      entry_points=dict(console_scripts=['oraculum=oraculum.cli:main']),
      include_package_data=True,
      data_files=data_files,
      install_requires=[
          'alembic',
          'bodhi-client',
          'celery',
          'Flask',
          'Flask-Cors',
          'Flask-Login',
          'Flask-OIDC',
          'Flask-Sqlalchemy',
          'fedfind',
          'icalendar',
          'lxml',
          'pygments',
          'python-bugzilla',
          'python-dateutil',
          'python-igraph',
          'pytz',
          'requests',
          'redis',
          'PyYAML',
      ],
      )
